@@ -68,7 +68,7 @@ var background_page = (function () {
        for (var i = 0; i < len; i++) {
          var extensionId = loginListeners[i];
          log.info("Notifying login listener: " + extensionId);
-         chrome.extension.sendMessage (extensionId, {
+         chrome.runtime.sendMessage (extensionId, {
                                          type: "login",
                                          login: request.login,
                                          domain: request.domain
@@ -385,11 +385,6 @@ var background_page = (function () {
                                    );
        }
        ,
-       get_base_domain: function (request, sender, callback) {
-	 
-	 chrome.tld.getBaseDomain (request.url, callback);
-       }
-       ,
        add_integrationscript_for_tabid: function (request, sender, callback) {
          
          addIntegrationScriptForTab(sender.tab.id
@@ -564,131 +559,6 @@ var background_page = (function () {
      }
    );
 
-
-   ///////////////////////////////////////////////////////////////////////
-   // 
-   // Window management related functions. In chromeless mode, we have specific
-   //  rules for tab management to make webapps feel more "native" than plain
-   //  web applications.
-   // 
-   ///////////////////////////////////////////////////////////////////////
-
-   // BIG TODO: due to async specific of chrome api, all this is sensitive to timing
-   //  issues / race conditions, so besides adding support for this directly in
-   //  Chromium, one way to mitigate this would be to add support for the 'ischromeless'
-   //  field in the tabs info structure retrieved from chrome API.
-   // 
-
-   /**
-    * Validates the presence of a given tab in a chromeless window. The validation
-    *  occurs based on specific rules:
-    *    - for a given chromeless window, only tabs related to a gievn webapp should
-    *       be allowed,
-    *    - tabs can be 'undocked' but not 'external' tab can be docked in,
-    * 
-    * TODO: right now the scheme is pretty naive and brittle, fix that
-    */
-   var validateChromelessTabForWindowId =
-     function (windowId, tabId, url, onInvalidTab) {
-       // TODO bail out right away?
-       var continuation =
-         (onInvalidTab && typeof(onInvalidTab) == "function")
-         ? onInvalidTab
-         : function (tabId) { log.error ("onInvalidTab callback is invalid"); };
-
-       // TODO use the new chrome.extension.getViews ({type: "tab"}) extension?
-       // TODO(bis): mmmh one level of indirection again?
-       chrome.windows.get(
-         windowId
-         , {populate: true}
-         , function (win) {
-           if (win.tabs.length == 1) {
-             return;
-           }
-           var diff = win.tabs.some (
-             function (curtab) {
-               if (curtab.id == tabId) {
-                 return false;
-               }
-               // TODO: usage of integration_script_tabs structure is bad
-               var infos = integration_script_tabs[curtab.id];
-               return infos
-                 && infos.domain
-                 && url.indexOf(infos.domain) == -1;
-             }
-           );
-           if (diff) {
-             // the tab corresponding to tabId
-             // shoudldn't be there
-             continuation(tabId);
-           }
-         }
-       );
-     }; // ) {
-
-   var onTabChanged = function (tabId, windowId, url) {
-     chrome.extension.isChromelessWindow(
-       tabId
-       , function (isChromeless) {
-         if (!isChromeless) {
-           return;
-         }
-         validateChromelessTabForWindowId(
-           windowId
-           , tabId
-           , url
-           , function (_tabId) {
-             chrome.windows.create({tabId: tabId});
-           }
-         );
-       } // function (isChromeless) {
-     ); // chrome.extension.isChromelessWindow
-   };
-   chrome.tabs.onCreated.addListener(
-     function(tab) {
-       if (tab && tab.url) {
-         onTabChanged(tab.id, tab.windowId, tab.url);
-       } // if (tab && tab.url) {
-     }
-   );
-   chrome.tabs.onUpdated.addListener (
-     function(tabId, changeInfo, tab) {
-       if (changeInfo && changeInfo.url) {
-         onTabChanged(tabId, tab.windowId, changeInfo.url);
-       }
-     }
-   );
-   chrome.tabs.onAttached.addListener(
-     function(tabId, attachInfo) {
-       chrome.extension.isChromelessWindow(
-           tabId
-         , function (isChromeless) {
-             if (!isChromeless) {
-               return;
-             }
-             // retrieve info about the given tab
-             // TODO: this get tiring bc of the sensitivity to
-             //  race conditions (or equivalent) created by request lags
-             chrome.tabs.get (
-               tabId
-               , function (tab) {
-                   // Finally perform the actual validation or the
-                   // new tab that got docked in
-                   validateChromelessTabForWindowId(
-                     attachInfo.newWindowId
-                     , tabId
-                     , tab.url
-                     , function (tabId) {
-                       chrome.windows.create({tabId: tab.id});
-                     }
-                   );
-                 } // function (tab) {
-             ); // chrome.tabs.get
-         } // function (isChromeless) {
-       ); // chrome.extension.isChromelessWindow
-     }
-   ); // tabs.onAttached
-
    return {
      /*
       *  Returns a potential message associated with a tab id (infobar)
