@@ -398,17 +398,17 @@ UnityGlobalPropertyInitializer = {
 
 	  unityInitWithDomain (domain);
 	} else {
-	  UnityContentScriptApi.getBaseDomain (document.location.href
-		                               , function (currentBaseDomain) {
-		                                 if ((domain.indexOf(currentBaseDomain,
-					                             domain.length-currentBaseDomain.length) == -1)) {
-			                           throw Error("invalid supplied domain "
-                                                               + domain
-                                                               + " does not have base suffix ("
-                                                               + currentBaseDomain + ")");
-		                                 }
-			                         unityInitWithDomain (domain);
-		                               });
+	  var hostname = window.location.hostname;
+	  var domainIdx = hostname.indexOf(domain);
+	  if (domain.length !== 0 &&  window.location.protocol !== 'file:' && domainIdx !== (hostname.length - domain.length)) {
+	    logger ("invalid supplied domain "
+                    + domain
+                    + " does not match with hostname '"
+                    + hostname
+		    + "'");
+	    return;
+	  }
+	  unityInitWithDomain (domain);
 	}
       }; // function unityInit
 
